@@ -53,8 +53,9 @@ our $use_objectv = 1;
 use constant FBIT => 128;
 
 sub hobodecode {
+    return unless defined $_[0];
     open my $fh, "| $^X -Mblib=../Encoder -Mblib=../Decoder author_tools/hobodecoder.pl -e" or die $!;
-    print $fh @_;
+    print $fh $_[0];
     close $fh;
 }
 
@@ -878,7 +879,7 @@ sub write_test_files {
         _write_file($make_name_file_name->($testno), $t->[2] . "\n");
     }
 
-    my $encoder = Sereal::Encoder->new;
+    my $encoder = Sereal::Encoder->new({protocol_version => $PROTO_VERSION});
     foreach my $i (0..$#RoundtripTests) {
         my $testno = @BasicTests + $i + 1;
         my $t = $RoundtripTests[$i];
